@@ -1,6 +1,6 @@
 # encoding=UTF-8
 
-# Copyright © 2007-2019 Jakub Wilk <jwilk@jwilk.net>
+# Copyright © 2007-2021 Jakub Wilk <jwilk@jwilk.net>
 #
 # This file is part of python-djvulibre.
 #
@@ -119,6 +119,9 @@ if sys.version_info >= (3, 2):
 else:
     array_tobytes = array.array.tostring
 
+if sys.version_info < (2, 7):
+    memoryview = None  # make pyflakes happy
+
 def run(*cmd, **kwargs):
     stdin = kwargs.pop('stdin', None)
     env = dict(os.environ)
@@ -547,6 +550,19 @@ class test_page_jobs():
         s = array_tobytes(buffer)
         assert_equal(s, b'\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xEF\xFF\xFF\xFF\xA4\xFF\xFF\xFF\xB8')
 
+        buffer = array.array('I', [0] * 4)
+        pixel_format = PixelFormatRgbMask(0xFF0000, 0xFF00, 0xFF, bpp=32)
+        assert_is(page_job.render(RENDER_COLOR, (0, 0, 10, 10), (0, 0, 2, 2), pixel_format, 1, buffer), buffer)
+        s = array_tobytes(buffer)
+        assert_equal(s, b'\xFF\xFF\xFF\x00' * 4)
+
+        if sys.version_info >= (3, 3):
+            buffer = bytearray(16)
+            memview = memoryview(buffer).cast('I', shape=(2, 2))
+            assert_is(page_job.render(RENDER_COLOR, (0, 0, 10, 10), (0, 0, 2, 2), pixel_format, 1, memview), memview)
+            s = bytes(buffer)
+            assert_equal(s, b'\xFF\xFF\xFF\x00' * 4)
+
 class test_thumbnails:
 
     def test(self):
